@@ -2,6 +2,9 @@
 def foo(): return "mock"  # fmt: skip
 if True: print("yay")  # fmt: skip
 for i in range(10): print(i)  # fmt: skip
+if True: print("this"); print("that")  # fmt: skip
+while True: print("loop"); break  # fmt: skip
+for x in [1, 2]: print(x); print("done")  # fmt: skip
 
 j =     1 # fmt: skip
 while j < 10: j += 1  # fmt: skip
